@@ -1,4 +1,7 @@
-from __future__ import print_function
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
+from zenutils.sixutils import *
 
 import os
 import sys
@@ -8,6 +11,7 @@ from pprint import pprint
 
 import click
 import yaml
+from zenutils import dictutils
 
 from .base import daemon_start
 from .base import daemon_stop
@@ -63,6 +67,7 @@ class DaemonApplication(object):
     def get_default_config(self):
         config = {
             "pidfile": "app.pid",
+            "stop-timeout": 30,
             "stop-signal": signal.SIGINT,
             "daemon": True,
             "workspace": os.getcwd(),
@@ -91,13 +96,14 @@ class DaemonApplication(object):
             config["pidfile"] = self.appname + ".pid"
 
     def load_config(self, config, **kwargs):
+        self.config = dictutils.Object({})
         self.appname = self.get_appname()
         self.config_file_path = self.get_config_file_path(config, self.appname)
         if self.config_file_path:
             print("Start application with config file: {}".format(self.config_file_path), file=sys.stderr)
         else:
             print("Start application without config file.", file=sys.stderr)
-        self.config = self.get_default_config()
+        self.config.update(self.get_default_config())
         self.config.update(self.load_config_from_config_file(self.config_file_path))
         for key, value in kwargs.items():
             self.update_config_item(self.config, key.replace("_", "-"), value)
@@ -138,7 +144,8 @@ class DaemonApplication(object):
             """
             pidfile = self.config["pidfile"]
             stop_signal = self.config["stop-signal"]
-            daemon_stop(pidfile, sig=stop_signal)
+            stop_timeout = self.config["stop-timeout"]
+            daemon_stop(pidfile, sig=stop_signal, stop_timeout=stop_timeout)
 
         @main.command()
         @click.option("--sleep-seconds", type=int, default=0, help="Wait some seconds after old application stopped and before new application started.")
@@ -147,7 +154,8 @@ class DaemonApplication(object):
             """
             pidfile = self.config["pidfile"]
             stop_signal = self.config["stop-signal"]
-            daemon_stop(pidfile, sig=stop_signal)
+            stop_timeout = self.config["stop-timeout"]
+            daemon_stop(pidfile, sig=stop_signal, stop_timeout=stop_timeout)
             if sleep_seconds:
                 time.sleep(sleep_seconds)
             daemon = self.config["daemon"]
