@@ -1,3 +1,8 @@
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
+from zenutils.sixutils import *
+
 import time
 import click
 from daemon_application import DaemonApplication
